@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import logging
 import re
-from collections import namedtuple
+from collections import defaultdict, namedtuple
 from datetime import date, datetime
 from enum import Enum
 from typing import Any
@@ -53,7 +53,12 @@ def hive_connection_function(
     from pyhive import hive
 
     connection = hive.connect(
-        username=username, password=password, host=host, port=port, database=database, auth=auth_method
+        username=username,
+        password=password,
+        host=host,
+        port=port,
+        database=database,
+        auth=auth_method,
     )
     return connection
 
@@ -126,7 +131,11 @@ def databricks_connection_function(host: str, http_path: str, token: str, databa
 
     logging.getLogger("databricks.sql").setLevel(logging.INFO)
     connection = sql.connect(
-        server_hostname=host, catalog=database, schema=schema, http_path=http_path, access_token=token
+        server_hostname=host,
+        catalog=database,
+        schema=schema,
+        http_path=http_path,
+        access_token=token,
     )
     return connection
 
@@ -205,7 +214,10 @@ class SparkSQLBase(DataSource):
         return columns
 
     def sql_get_table_columns(
-        self, table_name: str, included_columns: list[str] | None = None, excluded_columns: list[str] | None = None
+        self,
+        table_name: str,
+        included_columns: list[str] | None = None,
+        excluded_columns: list[str] | None = None,
     ):
         return f"DESCRIBE TABLE {table_name}"
 
@@ -254,6 +266,100 @@ class SparkSQLBase(DataSource):
         table_names = self._filter_include_exclude(table_names, include_tables, exclude_tables)
         return table_names
 
+    @staticmethod
+    def pattern_matches(spark_object_name: str, spark_object_name_pattern: str | None) -> bool:
+        if spark_object_name_pattern is None:
+            return True
+        else:
+            pattern_regex = spark_object_name_pattern.replace("%", ".*").lower()
+            is_match = re.fullmatch(pattern_regex, spark_object_name.lower())
+            return bool(is_match)
+
+    def get_included_table_names(
+        self,
+        query_name: str,
+        include_patterns: list[dict[str, str]],
+        exclude_patterns: list[dict[str, str]],
+        table_names_only: bool = False,
+    ) -> list[str]:
+        query = Query(
+            data_source_scan=self.data_source_scan,
+            unqualified_query_name=query_name,
+            sql=self.sql_find_table_names(),
+        )
+        query.execute()
+        table_names = [row[1] for row in query.rows]
+
+        included_table_names = [
+            table_name
+            for table_name in table_names
+            if any(
+                self.pattern_matches(table_name, include_pattern["table_name_pattern"])
+                for include_pattern in include_patterns
+            )
+            and not any(
+                self.pattern_matches(table_name, exclude_pattern["table_name_pattern"])
+                and (exclude_pattern.get("column_name_pattern") == "%" or table_names_only)
+                for exclude_pattern in exclude_patterns
+            )
+        ]
+
+        return included_table_names
+
+    def column_table_pattern_match(
+        self, table_name: str, column_name: str, profiling_patterns: list[dict[str, str]]
+    ) -> bool:
+        column_table_name_pattern_match = any(
+            (
+                self.pattern_matches(table_name, pattern["table_name_pattern"])
+                and self.pattern_matches(column_name, pattern.get("column_name_pattern"))
+            )
+            for pattern in profiling_patterns
+        )
+        return column_table_name_pattern_match
+
+    def get_tables_columns_metadata(
+        self,
+        query_name: str,
+        include_patterns: list[dict[str, str]] | None = None,
+        exclude_patterns: list[dict[str, str]] | None = None,
+        table_names_only: bool = False,
+    ) -> dict[str, str] | None:
+        if (not include_patterns) and (not exclude_patterns):
+            return []
+        included_table_names: list[str] = self.get_included_table_names(
+            query_name, include_patterns, exclude_patterns, table_names_only=table_names_only
+        )
+        if table_names_only:
+            return included_table_names
+        tables_and_columns_metadata = defaultdict(dict)
+        for table_name in included_table_names:
+            query = Query(
+                data_source_scan=self.data_source_scan,
+                unqualified_query_name=f"get-tables-columns-metadata-describe-table-{table_name}-spark",
+                sql=f"DESCRIBE TABLE {table_name}",
+            )
+            query.execute()
+            columns_metadata = query.rows
+
+            partition_indices = [
+                i for i in range(len(columns_metadata)) if columns_metadata[i][0].startswith("# Partition")
+            ]
+            if partition_indices:
+                columns_metadata = columns_metadata[: partition_indices[0]]
+
+            if columns_metadata and len(columns_metadata) > 0:
+                for column_name, column_datatype, _ in columns_metadata:
+                    column_name_included = self.column_table_pattern_match(table_name, column_name, include_patterns)
+                    column_name_excluded = self.column_table_pattern_match(table_name, column_name, exclude_patterns)
+                    if column_name_included and not column_name_excluded:
+                        tables_and_columns_metadata[table_name][column_name] = column_datatype
+
+        if tables_and_columns_metadata:
+            return tables_and_columns_metadata
+        else:
+            return None
+
     @staticmethod
     def _filter_include_exclude(
         item_names: list[str], included_items: list[str], excluded_items: list[str]
